summaryrefslogtreecommitdiffstats
path: root/src/dbusHAL.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dbusHAL.h')
-rw-r--r--src/dbusHAL.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/dbusHAL.h b/src/dbusHAL.h
index d3a3754..3b52045 100644
--- a/src/dbusHAL.h
+++ b/src/dbusHAL.h
@@ -106,10 +106,10 @@ private:
/*!
* This boolean represent information if KPowersave could claim the
* org.freedesktop.Policy.Power interface from the D-Bus
- * \li true: if aquired
+ * \li true: if acquired
* \li false: if not
*/
- bool aquiredPolicyPower;
+ bool acquiredPolicyPower;
/* D-Bus helper functions */
//! to initialise the connection to D-Bus
@@ -142,8 +142,8 @@ public:
//! to close the connection to D-Bus and HAL
bool close();
- //! to aquire the org.freedesktop.Policy.Power interface
- bool aquirePolicyPowerIface();
+ //! to acquire the org.freedesktop.Policy.Power interface
+ bool acquirePolicyPowerIface();
//! to release the org.freedesktop.Policy.Power interface
bool releasePolicyPowerIface();
//! to check if the org.freedesktop.Policy.Power interface has an owner
@@ -155,7 +155,7 @@ public:
//! to get information if KPowersave is connected to HAL
bool isConnectedToHAL();
//! to get info about claim org.freedesktop.Policy.Power interface
- bool aquiredPolicyPowerInterface();
+ bool acquiredPolicyPowerInterface();
//! return the current HAL context
LibHalContext *get_HAL_context();